==> haskell-network-uri-2.6.1.0-5-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-network-uri.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: network-uri
version: 2.6.1.0
id: network-uri-2.6.1.0-GzRvaV3udR3JtWfa3CLYOw
key: network-uri-2.6.1.0-GzRvaV3udR3JtWfa3CLYOw
license: BSD3
maintainer: ezra@ezrakilty.net
homepage: https://github.com/haskell/network-uri
synopsis: URI manipulation
description:
    This package provides an URI manipulation interface.
    .
    In network-2.6 the @Network.URI@ module was split off from the
    network package into this package. If you'\''re using the @Network.URI@
    module you can automatically get it from the right package by adding
    this to your .cabal file:
    .
    > flag network-uri
    >   description: Get Network.URI from the network-uri package
    >   default: True
    >
    > library
    >   -- ...
    >   if flag(network-uri)
    >     build-depends: network-uri >= 2.6, network >= 2.6
    >   else
    >     build-depends: network-uri < 2.6, network < 2.6
    .
    That is, get the module from either network < 2.6 or from
    network-uri >= 2.6.
category: Network
exposed: True
exposed-modules:
    Network.URI
abi: de9d1b3d1b94439e43d151211d7561d8
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/network-uri-2.6.1.0
library-dirs: /usr/lib/ghc-8.0.2/site-local/network-uri-2.6.1.0
dynamic-library-dirs: /usr/lib/x86_64-linux-ghc-8.0.2
data-dir: /usr/share/x86_64-linux-ghc-8.0.2/network-uri-2.6.1.0
hs-libraries: HSnetwork-uri-2.6.1.0-GzRvaV3udR3JtWfa3CLYOw
depends:
    base-4.9.1.0 deepseq-1.4.2.0 parsec-3.1.11-1CA7c0vSU7tJHGhveOjoXR
haddock-interfaces: /usr/share/doc/haskell-network-uri/html/network-uri.haddock
haddock-html: /usr/share/doc/haskell-network-uri/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-network-uri-2.6.1.0-7-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-network-uri.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: network-uri
version: 2.6.1.0
id: network-uri-2.6.1.0-4GXMsZ4PWr49y3TK4YgSYK
key: network-uri-2.6.1.0-4GXMsZ4PWr49y3TK4YgSYK
license: BSD3
maintainer: ezra@ezrakilty.net
homepage: https://github.com/haskell/network-uri
synopsis: URI manipulation
description:
    This package provides an URI manipulation interface.
    .
    In network-2.6 the @Network.URI@ module was split off from the
    network package into this package. If you'\''re using the @Network.URI@
    module you can automatically get it from the right package by adding
    this to your .cabal file:
    .
    > flag network-uri
    >   description: Get Network.URI from the network-uri package
    >   default: True
    >
    > library
    >   -- ...
    >   if flag(network-uri)
    >     build-depends: network-uri >= 2.6, network >= 2.6
    >   else
    >     build-depends: network-uri < 2.6, network < 2.6
    .
    That is, get the module from either network < 2.6 or from
    network-uri >= 2.6.
category: Network
exposed: True
indefinite: False
exposed-modules:
    Network.URI
abi: 0d8dbc66a8173770b7f27b72bc5a4600
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/network-uri-2.6.1.0
library-dirs: /usr/lib/ghc-8.2.1/site-local/network-uri-2.6.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.1/network-uri-2.6.1.0
hs-libraries: HSnetwork-uri-2.6.1.0-4GXMsZ4PWr49y3TK4YgSYK
depends:
    base-4.10.0.0 deepseq-1.4.3.0 parsec-3.1.11-5WCVqUZr6ypLPXtYWYsMnh
abi-depends: base-4.10.0.0=835a16347ec1b210054efd02671c29ee
             deepseq-1.4.3.0=5db6f9c28d6213bd6646f988460dacd0
             parsec-3.1.11-5WCVqUZr6ypLPXtYWYsMnh=e1133adbf062e57f52fe5f364651e21e
haddock-interfaces: /usr/share/doc/haskell-network-uri/html/network-uri.haddock
haddock-html: /usr/share/doc/haskell-network-uri/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
